********************************************************************************
* EKP 2018 - Constitutional Rules as Determinants of Social Infrastructure	   *
* Preparation of CCP Constitution Data										   *	
********************************************************************************

* Loading CCP data:
*******************
set more off
use ccpcncv1_0, clear

* Merging in Hall and Jones (1999) and Persson and Tabellini (2002/2003) data:
******************************************************************************
replace country="Belarus" if country=="Belarus (Byelorussia)"
replace country="Cyprus (G)" if country=="Cyprus"
replace country="Dominican Re" if country=="Dominican Republic"
replace country="Germany" if country=="German Federal Republic"
replace country="Italy" if country=="Italy/Sardinia"
replace country="New Zeland" if country=="New Zealand"
replace country="Papua N. Guin" if country==""
replace country="Russia" if country=="Russia (Soviet Union)"
replace country="Slovak Republic" if country=="Slovakia"
replace country="South Korea" if country=="Korea, Republic Of"
replace country="Sri Lanka" if country=="Sri Lanka (Ceylon)"
replace country="St. Vincent&G" if country=="St. Vincent And The Grenadines"
replace country="Trinidad&Tob" if country=="Trinidad And Tobago"
replace country="Turkey" if country=="Turkey/Ottoman Empire"
replace country="USA" if country=="United States Of America"
replace country="Zimbabwe" if country=="Zimbabwe (Rhodesia)"
merge 1:1 country using HJ_PT_data
keep if _merge==3
drop _merge


*********************************************************************	
* I) Dropping Irrelevant Variables									*
*********************************************************************
drop access amparo arms asylum attend census childwrk citdep citren citrev* civil/*
*/ civmar colony colrule cowcode docs doctit doubjep endyear evntid evnttype/*
*/ evntyear excrim fndfam grjury headforn hoglegr hogpard hogrest* hosdecim hosrest*/*
*/ hospard judsal lang langsrce length lhcohort lhname lhrest* lhterm life marriage/*
*/ matequal miranda model nomil preamble preambw profleg rghtwrds samesexm source/*
*/ systid systyear testate translat treatap* treatini* treatrvw uhname unconper/*
*/ *_article *_comments


*********************************************************************
* II) Variables that Required Recoding							    *
*********************************************************************
* Guarantee equall access to higher education - 'acfree'
* Amendment: supermajority provided - 'amndamaj'
* reedom of assembly - 'assem'
* Earnings disclosure of legislators- 'assets'
* Freedom of association - 'assoc'
* Central bank: presence - 'bank'
* Criminal procedures: mentions bankcrupty law - 'bankrupt'
* Who is bound by rights provisions - 'binding'
* Right to conduct or establish a business - 'busines'
* Criminal procedures: status of captial punishment - 'cappun'
* Corruption commission: presence - 'cc'
* ention of consumer rights or protection - 'conright'
* Criminal procedures: status of corporal punishment - 'corppun'
* Criminal procedures: right to counsel - 'couns'
* Duty of state: promote culture - 'cultrght'
* Criminal procedures: forbids detention of debtors - 'debtors'
* Deputy executive: presence of deputy - 'depexec'
* Individual's right to self-determination - 'devlpers'
* Criminal procedures: mention of due process - 'dueproc'
* Economic plans: mention - 'econplan'
* Education: compulsory - 'edcomp'
* Education: free - 'edfree'
* Limits on money used for campaigns - 'electfin'
* Emergency provisions: approver(s) - 'emappr_1'-'emappr_7'
* Emergency provisions: conditions for declaring - 'emcond_1'-'emcond_5'
* Emergency provisions: rights restrictions during emergency - 'emrights'
* Mention of equality before the law - 'equal'
* Integration of ethnic communities - 'ethincl'
* Executive independence - 'execindp'
* Number of executives - 'execnum'
* Exporopriation: purposes - 'expcond_1'-'expcond_7'
* Criminal procedures: punishment by ex post facto laws prohibited - 'expost'
* Freedom of expression or speech - 'express'
* Expropriation: allowed or not - 'exprop'
* Criminal procedures: right to fair trial - 'fairtri'
* Criminal procedures: right to redress in the case of judical errors - 'falseimp'
* Recognition of which subnational governments - 'federal_1'-'federal_3'
* Federal review of subnational legislation allowed - 'fedrev'
* Right to a free or competitive market - 'freecomp'
* Secret ballots - 'freeelec'
* Freedom of movement - 'freemove'
* Religion: freedom of religion - 'freerel'
* Criminal procedures: protection from unjustified restrain - 'habcorp'
* Health care should be provided free of charge - 'healthf'
* Right to heatlh care - 'healthr'
* Head of government: presence of decree pwoer - 'hogdec'
* Head of state: grounds for dismissal - 'hosdcond_1'-'hosdcond_5'
* Head of state: presence of decree power - 'hosdec'
* Head of state: presence of dismissal procedure - 'hosdiss'
* Chambers in legislature - 'housenum'
* Human rights comission: presence - 'hr'
* Protection against ultra-vires administrative actions - 'illadmin'
* Right to view government documents - 'infoacc'
* Legislative initiatives allowed - 'initiat'
* Provisions concerning international law - 'intlaw'
* Mention of international organizations - 'intorgs'
* Mention of intellectual property rights - 'intprop_1'-'intprop_4'
* Investigation of the executive by the legislature - 'invexe'
* Investigation of the executive by the legislature (different coding) - 'leginvexe_no'
* Judicial council: presence - 'jc'
* Right to join trade unions - 'jointrde'
* Dismissal of judges: procedure mentioned - 'jrem'
* Presence of certain specialized courts - 'judcrts_1'-'judcrts_9'
* Decisions of the highest court are final - 'judfin'
* Legislation: supermajority necessary for any issues - 'legsupr'
* First chamber: power to legislate - 'lhlegis'
* First chamber: selection procedure - 'lhselect_1'-'lhselect_3'
* Right to protect one's reputation from libel - 'libel'
* Media commission:  presence - 'medcom'
* Reference to operation of media market - 'medmark_1'-'medmark_6'
* Right to choose ones occupation - 'occupate'
* Obligations to transfer wealth to particular groups - 'opgroup'
* Freedom of opinion or conscience - 'opinion'
* Legislation: ability to override vetoes - 'override'
* Political parties: any references - 'part'
* Political parties: right to form - 'partrght'
* Criminal procedures: pre-trial release possible - 'prerel' 
* Criminal procedures: presumption of innocence in trials - 'presinoc'
* Freedom of press - 'press'
* Right to privacy - 'privacy'
* Right to own property - 'proprght'
* Duty of state: health care - 'provhlth'
* Legislatorial meetings are public or private - 'pubmeet'
* Legislatorial deliberations are published or not - 'pubmin'
* Criminal procedures: public trials required - 'pubtri'
* Referenda allowed - 'referen'
* Religion: religious organizations are given tax free status - 'reltax'
* Process specified to remove individual legislators - 'remleg'
* Right to just remuneration or equal payment for work - 'remuner'
* Criminal procedures: right to appeal - 'rghtapp'
* Mention of rule of law - 'rulelaw'
* Right to safe or healthy working conditions - 'safework'
* Right to enjoy the benefits of scientific progress - 'scifree'
* People's right of self-determination - 'selfdet'
* Religion: separation of church and state - 'seprel'
* Right to shelter - 'shelter'
* Status of slavery - 'slave'
* Mention of (socio-) economic rights - 'socecon'
* Reference to social security of society or the nation - 'socsec'
* Special legislation: types of specifal legislation specified - 'specleg_1'-'specleg_5'
* Criminal procedures: right to speedy trial - 'speedtri'
* Right to an adequate or reasonable standard of living - 'standliv'
* Duty of people: pay taxes - 'taxes'
* Reference to geographic borders - 'terr'
* Right to transfer property freely - 'transfer'
* Criminal procedures: right to interpreter if accused cannot understand language - 'trilang'
* Second chamber: presence of quote - 'uhquota'
* Second chamber: selection procedure - 'uhselect_1'-'uhselect_3'
* Amendment: presence of unamendable sections - 'unamend'
* Restrictions on voting: additional restictions on eligibility - 'votelim_1','votelim_2','votelim_4'-'votelim_6','votelim_9'-'votelim_12'
* Restrictions on voting: presence of restrictions - 'voteres'
* Universal adult suffrage - 'voteun'
* Declarer of war - 'war_1'-'war_5','war_7'
* Criminal procedures: mention of nulla poena sine lege - 'wolaw'
* Duty of people: work - 'work'
replace execnum=1 if execnum==2
rename execnum execnum_2
replace housenum=1 if housenum==2
gen leginvexe_no=0
replace leginvexe_no=1 if invexe==2
replace prevlead=1 if prevlead==2

local vars="acfree amndamaj assem assets assoc bank bankrupt binding busines cappun cc conright " ///
		 + "corppun couns cultrght debtors depexec devlpers dueproc econplan edcomp edfree " ///
	     + "electfin emappr_1 emappr_2 emappr_3 emappr_4 emappr_5 emappr_6 emappr_7 emcond_1 " ///
	     + "emcond_2 emcond_3 emcond_4 emcond_5 emrights equal ethincl execindp execnum_2 " ///
		 + "expcond_1 expcond_2 expcond_3 expcond_4 expcond_5 expcond_6 expcond_7 expost " ///
		 + "express exprop fairtri falseimp federal_1 federal_2 federal_3 fedrev freecomp " ///
		 + "freeelec freemove freerel habcorp healthf healthr hogdec hosdcond_1 hosdcond_2 " ///
		 + "hosdcond_3 hosdcond_4 hosdcond_5 hosdec hosdiss housenum hr illadmin infoacc initiat " ///
		 + "intlaw intorgs intprop_1 intprop_2 intprop_3 intprop_4 invexe jc jointrde jrem " ///
		 + "judcrts_1 judcrts_2 judcrts_3 judcrts_4 judcrts_5 judcrts_6 judcrts_7 judcrts_8 " ///
		 + "judcrts_9 judind legsupr lhlegis lhselect_1 lhselect_2 lhselect_3 libel medcom " ///
		 + "medmark_1 medmark_2 medmark_3 medmark_4 medmark_5 medmark_6 occupate opgroup opinion " ///
		 + "override part partrght prerel presinoc press privacy proprght provhlth pubmeet " ///
		 + "pubmin pubtri referen reltax remleg remuner rghtapp rulelaw safework scifree " ///
		 + "selfdet seprel shelter slave socecon socsec specleg_1 specleg_2 specleg_3 specleg_4 " ///
		 + "specleg_5 speedtri standliv taxes terr transfer trilang uhquota uhselect_1 uhselect_2 " ///
		 + "uhselect_3 unamend votelim_1 votelim_2 votelim_4 votelim_5 votelim_6 votelim_9 " ///
		 + "votelim_10 votelim_11 votelim_12 voteres voteun war_1 war_2 war_3 war_4 war_5 " ///
		 + "war_7 wolaw work"

foreach k in `vars' {
gen `k'_temp=0
replace `k'_temp=1 if `k'==1
_crcslbl `k'_temp `k'
drop `k'
rename `k'_temp `k'
}

* Guarantee equal access to higher education - 'achighed'
* Central bank: goals - 'bankgoal'
* Censorship prohibited - 'censor'
* Military: commander in chief - 'comchief'
* Right to strike - 'strike'
* Status of torture - 'torture'
local vars="achighed bankgoal censor comchief strike torture"

foreach k in `vars' {
forvalues i=1(1)2 {
gen `k'_`i'=0
replace `k'_`i'=1 if `k'==`i'
_crcslbl `k'_`i' `k'
}
drop `k'
}

* Status of customary international law - 'custlaw2'
* Criminal procedures: right to examine evidence or confront witnesses - 'examwit'
* Description of the structure of the state - 'fedunit'
* Ability of state to operate electronic media - 'govmed'
* Head of of government: immunity - 'hogimm'
* Head of state: decree implementation procedure - 'hoselect'
* Head of state: immunity - 'hosimm'
* Legislation: power of approver to reject parts of legislation - 'legapppt'
* First chamber: specification of electoral system - 'lhelsys'
* Presence of electoral oversight bodies - 'oversght'
* Political parties: presence of prohibited parties - 'partprh'
* Second chamber: specification of electoral system - 'uhelsys'
local vars="custlaw2 examwit fedunit govmed hogimm hoselect hosimm legapppt lhelsys oversght " ///
		 + "partprh uhelsys"

foreach k in `vars' {
forvalues i=1(1)3 {
gen `k'_`i'=0
replace `k'_`i'=1 if `k'==`i'
_crcslbl `k'_`i' `k'
}
drop `k'
}

* Emergency provisions: declarer - 'emdecl'
forvalues i=1(1)4 {
gen emdecl_`i'=0
replace emdecl_`i'=1 if emdecl==`i'
_crcslbl emdecl_`i' emdecl
}
forvalues i=5(2)7 {
gen emdecl_`i'=0
replace emdecl_`i'=1 if emdecl==`i'
_crcslbl emdecl_`i' emdecl
}
drop emdecl

 * Religion: official religion specified  - 'offrel'
foreach i of numlist 1 3 {
gen offrel_`i'=0
replace offrel_`i'=1 if offrel==`i'
_crcslbl offrel_`i' offrel
}
drop offrel

* Expropriation: compensation required - 'exprcomp'
* Legislation: default mode of approval - 'legappdf'
local vars="exprcomp legappdf"

foreach k in `vars' {
forvalues i=1(1)4 {
gen `k'_`i'=0
replace `k'_`i'=1 if `k'==`i'
_crcslbl `k'_`i' `k'
}
drop `k'
}

* Legislation: approver of legislation passed by legislature - 'legapp'
foreach i of numlist 1 4 {
gen legapp_`i'=0
replace legapp_`i'=1 if legapp==`i'
_crcslbl legapp_`i' legapp
}
drop legapp

* Immunity of legislators - 'immunity'
foreach i of numlist 2 3 {
gen immunity_`i'=0
replace immunity_`i'=1 if immunity==`i'
_crcslbl immunity_`i' immunity
}
drop immunity

* Head of of government: selection process - 'hogelect'
forvalues i=2(1)4 {
gen hogelect_`i'=0
replace hogelect_`i'=1 if hogelect==`i'
_crcslbl hogelect_`i' hogelect
}
drop hogelect hogelect_2 hogelect_3

* Head of government: replacement procedure - 'hogsucc'
* Head of state: repacement procedure - 'hossucc'
* Body with ability to dismiss legislature - 'legdiss'
local vars="hogsucc hossucc legdiss"

foreach k in `vars' {
foreach i of numlist 1 2 4 {
gen `k'_`i'=0
replace `k'_`i'=1 if `k'==`i'
_crcslbl `k'_`i' `k'
}
drop `k'
}

* Interpellation of the executive by the legislature - 'intexec'
foreach i of numlist 1 2 3 5 {
gen intexec_`i'=0
replace intexec_`i'=1 if intexec==`i'
_crcslbl intexec_`i' intexec
}
drop intexec

* Legislation: body, or bodies, who can override vetoes - 'overwho'
foreach i of numlist 1 3 4 5 6 {
gen overwho_`i'=0
replace overwho_`i'=1 if overwho==`i'
_crcslbl overwho_`i' overwho
}
drop overwho

* Head of state: electoral system - 'hoselsys'
foreach i of numlist 1 4 5 6 7 {
gen hoselsys_`i'=0
replace hoselsys_`i'=1 if hoselsys==`i'
_crcslbl hoselsys_`i' hoselsys
}
drop hoselsys

* Amendment: what supermajority - 'amndapct'
gen amndapct_1_2=0
gen amndapct_3_5=0
gen amndapct_2_3=0
gen amndapct_3_4=0 
replace amndapct_1_2=1 if amndapct==1
replace amndapct_3_5=1 if amndapct==2
replace amndapct_2_3=1 if amndapct==3
replace amndapct_3_4=1 if amndapct==4
label variable amndapct_1_2 "amendment: 1/2 supermajority needed"
label variable amndapct_3_5 "amendment: 3/5 supermajority needed"
label variable amndapct_2_3 "amendment: 2/3 supermajority needed"
label variable amndapct_3_4 "amendment: 3/4 supermajority needed"
drop amndapct

* Presence of attorney general- 'atgen'
gen atgen_temp=0
replace atgen_temp=1 if atgen==1|atgen==2|atgen==3|atgen==4|atgen==5
_crcslbl atgen_temp atgen
drop atgen
rename atgen_temp atgen

* Head of state: term length - 'hosterm'
gen hosterm_under5=0
gen hosterm_over5=0
replace hosterm_under5=1 if hosterm>0 & hosterm<6
replace hosterm_over5=1 if hosterm>5
_crcslbl hosterm_under5 hosterm
_crcslbl hosterm_over5 hosterm
drop hosterm

* Head of government: term limits - 'hogterml'
* Head of state: term limits - 'hosterml'
* First chamber: term limits - 'lhtrmlim'
* Second chamber: term limits - 'uhtrmlim'
local vars="hogterml hosterml lhtrmlim uhtrmlim"

foreach k in `vars' {
gen `k'_5=0
replace `k'_5=1 if `k'==5
_crcslbl `k'_5 `k'
drop `k'
}

* Legislation: proportion of the vote necessary to override a veto - 'overpct'
gen overpct_1_2=0
gen overpct_3_5=0
gen overpct_2_3=0
gen overpct_3_4=0 
replace overpct_1_2=1 if overpct==2
replace overpct_3_5=1 if overpct==3
replace overpct_2_3=1 if overpct==4
replace overpct_3_4=1 if overpct==5
label variable overpct_1_2 "Legislation: proportion of the vote necessary to override a veto: 1/2 majority needed"
label variable overpct_3_5 "Legislation: proportion of the vote necessary to override a veto: 3/5 majority needed"
label variable overpct_2_3 "Legislation: proportion of the vote necessary to override a veto: 2/3 majority needed"
label variable overpct_3_4 "Legislation: proportion of the vote necessary to override a veto: 3/4 majority needed"
drop overpct

* Second chamber: minimum age - 'uhage':
gen uhage_under22=0
gen uhage_23_33=0
gen uhage_over33=0
replace uhage_under22=1 if uhage<23
replace uhage_23_33=1 if uhage>2 & uhage<34
replace uhage_over33=1 if uhage>33
_crcslbl uhage_under22 uhage
_crcslbl uhage_23_33 uhage
_crcslbl uhage_over33 uhage
drop uhage

* Second chamber: term length - 'uhterm':
destring uhterm, force replace
replace uhterm=0 if uhterm==.
gen uhterm_3_5=0
gen uhterm_over5=0
replace uhterm_3_5=1 if uhterm>2 & uhterm<6
replace uhterm_over5=1 if uhterm>5 & uhterm<10
_crcslbl uhterm_3_5 uhterm
_crcslbl uhterm_over5 uhterm
drop uhterm
 
* Combining existing constiutional variables:
gen amndapct_345=amndapct_3_4+amndapct_3_5
gen censor_12=censor_1+censor_2
gen custlaw2_123=custlaw2_1+custlaw2_2+custlaw2_3
gen emdecl_13=emdecl_1+emdecl_3
gen emdecl_457=emdecl_4+emdecl_5+emdecl_7
gen expcond_137=expcond_1+expcond_3+expcond_7
replace expcond_137=1 if expcond_137>0
gen expcond_2456=expcond_2+expcond_4+expcond_5+expcond_6
replace expcond_2456=1 if expcond_2456>0
gen exprcomp_1234=exprcomp_1+exprcomp_2+exprcomp_3+exprcomp_4
gen fedunit_12=fedunit_1+fedunit_2
gen hogsucc_12=hogsucc_1+hogsucc_2
gen hoselsys_4567=hoselsys_4+hoselsys_5+hoselsys_6+hoselsys_7
gen hosimm_12=hosimm_1+hosimm_2
replace hosimm_12=1 if hosimm_12>0
gen intexec_123=intexec_1+intexec_2+intexec_3
gen intprop_1234=intprop_1+intprop_2+intprop_3+intprop_4
replace intprop_1234=1 if intprop_1234>0
gen legapppt_123=legapppt_1+legapppt_2+legapppt_3
gen lhelsys_12=lhelsys_1+lhelsys_2
gen medmark_12345=medmark_1+medmark_2+medmark_3+medmark_4+medmark_5
replace medmark_12345=1 if medmark_12345>0
gen overpct_2_3_3_5=overpct_2_3+overpct_3_5
gen oversght_123=oversght_1+oversght_2+oversght_3
gen overwho_13456=overwho_1+overwho_3+overwho_4+overwho_5+overwho_6
gen partprh_23=partprh_2+partprh_3
gen strike_12=strike_1+strike_2
gen torture_12=torture_1+torture_2
gen uhelsys_123=uhelsys_1+uhelsys_2+uhelsys_3
gen war_13=war_1+war_3
gen war_47=war_4+war_7  

* Dropping variables not needed for emprical analysis (because they were previously combined or lack variation)
drop amndapct_1_2 amndapct_2_3 bankgoal_2 cabdiss* challeg* comchief_2 emappr_2 emappr_3 emappr_4/*
*/ emappr_5 emappr_6 emappr_7 emdecl_2 emother* examwit_1 examwit_2 exsess* govmed_1 govmed_3/*
*/ hogimm_1 hogimm_3 hogsucc_4 hogterml_5 hosimm_3 immunity_3 interp* judcrts_3 judcrts_4 judcrts_5/*
*/ judcrts_6 judcrts_7 judcrts_8 judcrts_9 legapp_4 legappdf_1 legappdf_2 legappdf_3 legdiss_2/*
*/ legdiss_4 legrep lhelsys_3 lhselect_1 lhselect_2 medmark_6 overpct_3_4 partprh_1 partunco*/*
*/ transfer uhage_23_33 uhage_over33 uhterm_over5 votelim_10 votelim_11 votelim_12 votelim_2/*
*/ votelim_4 votelim_5 votelim_6 votelim_9 war_2 war_5 emappr_8 emappr_90 emappr_96 emappr_97/*
*/ emappr_98 emcond_90 emcond_96 emcond_97 emcond_98 emcond_6 envpart_11 envpart_13 envpart_90/*
*/ envpart_97 envpart_96 envpart_98 expcond_90 expcond_96 expcond_97 expcond_98 federal_96/*
*/ federal_97 federal_98 hosdcond_90 hosdcond_96 hosdcond_97 hosdcond_98 income_2 income_7/*
*/ income_90 income_96 income_97 income_98 indpolgr_3 indpolgr_4 indpolgr_5 indpolgr_90/*
*/ indpolgr_96 indpolgr_97 indpolgr_98 initiatp_3 initiatp_90 initiatp_96 initiatp_97 initiatp_98/*
*/ intprop_90 intprop_96 intprop_97 intprop_98 judcrts_96 judcrts_97 judcrts_98 lhselect_90/*
*/ lhselect_96 lhselect_97 lhselect_98 medmark_7 medmark_90 medmark_96 medmark_97 medmark_98/*
*/ specleg_96 specleg_97 specleg_98 uhselect_90 uhselect_96 uhselect_97 uhselect_98 votelim_3/*
*/ votelim_7 votelim_8 votelim_13 votelim_14 votelim_15 votelim_90 votelim_96 votelim_97/*
*/ votelim_98 war_6 war_8 war_90 war_96 war_97 war_98 amndapct_3_4 amndapct_3_5 censor_1 censor_2/*
*/ custlaw2_1 custlaw2_2 custlaw2_3 emdecl_1 emdecl_3 emdecl_4 emdecl_5 emdecl_7 expcond_1/*
*/ expcond_3 expcond_7 expcond_2 expcond_5 expcond_4 expcond_6 exprcomp_1 exprcomp_2 exprcomp_3/*
*/ exprcomp_4 fedunit_1 fedunit_2 hoselsys_4 hoselsys_5 hoselsys_6 hoselsys_7 hosimm_1 hosimm_2/*
*/ intexec_1 intexec_2 intexec_3 intprop_1 intprop_2 intprop_3 intprop_4 legapppt_1 legapppt_2/*
*/ legapppt_3 lhelsys_1 lhelsys_2 medmark_1 medmark_2 medmark_3 medmark_4 medmark_5 overpct_2_3/*
*/ overpct_3_5 oversght_1 oversght_2 oversght_3 overwho_1 overwho_3 overwho_4 overwho_5 overwho_6/*
*/ partprh_2 partprh_3 strike_1 strike_2 torture_1 torture_2 uhelsys_1 uhelsys_2 uhelsys_3/*
*/ war_1 war_3 war_4 war_7 hogsucc_1 hogsucc_2


*********************************************************************	
* III) Dropping Variables with Imprecise Definitions				*
*********************************************************************
drop anthem artists bankrupt buildsoc cabinet camppubf capital childpro commit/*
*/ compvote concop concopw* conright custlaw democ depname dignity educate electsam/*
*/ electsch em env envpart* envref* evidence exinst fedsep figures flag forinves/*
*/ fortrad god hocop hocopw* hogage hogname hogid hosage hosid hoshog hosname/*
*/ hosstaff hosterm_over5 inalrght income* indcon inherit infoaccw intexec_5 intrght*/*
*/ judretir  jury juvenile langprot langnatw langoffw legjoint leisure levjud lhage/*
*/ lhlead lhquota lhquotad* lhseats market ombuds military milserv motto natcit oath/*
*/ nat offrelw overthrw part partprf petition prevcond prevlead prisonrg provwork/*
*/ quorum radio referenp* quorumw regions recvote region rellawv resrce resrces*/*
*/ resenex rightres* science socecon socsec solid rightsw seccess socialsm telecom/*
*/ terror tranprov treat truthcom tv treatst uhcohort uhlead vicright votemin/*
*/ lhseats uhseats 


*********************************************************************	
* IV) Dropping Variables that Lack Variation 						*
*********************************************************************
drop prtyduty tradeun legisl lhlegis 


*********************************************************************	
* V) Dropping/Recoding Variables with Ambiguous Codings:			*
*********************************************************************
drop amend cruelty custlaw2_123 devlpers freeelec hosimm_12 hosterml_5 intexec_123/*
*/ invexe judprec judind lhtrmlim_5 occupate offrel_3 press privacy safework/*  
*/ slave uhtrmlim_5 


*********************************************************************	
* VI) Dropping/Combining Variables Because of High Correlations:	*
*********************************************************************
gen edcompfree=edcomp+edfree
replace edcompfree=1 if edcompfree>0
gen assocexpressopinion=assoc+express+opinion
replace assocexpressopinion=1 if assocexpressopinion>0
drop overwho_13456 uhlegisl hogelect_4 hogdiss edcomp edfree assoc express/*
*/ opinion explim* 


*********************************************************************	
* VII) Dropping Variables with to Conditional Codings:				*
*********************************************************************
drop counscos depsel edcompl edfreel hogdcond* hogdecex hogdecim hosdecex indpolgr*/*
*/ initiatp* jremcon* judfin leg_in* rellaw* indcit uhquotad* uhrest* hogterm


* Renaming variables:
**********************
rename electfin LimitsOnCampaignDonations
rename partprh_23 PartiesCanBeProhibited
rename uhquota MinorityQuotaInLegislature
rename lhelsys_12 LegChamber1IsElected
rename uhelsys_123 LegChamber2IsElected
rename emcond_4 ReasonStateEmergency_General
rename execnum_2 NumberOfExec_1
rename emdecl_13 ExecCanDeclareStateEmergency
rename hossucc_1 HOSReplace_NoAutomaticSelection
rename remleg IndivLegislatorsCanBeRemoved
rename leginvexe_no LegCannotInvestigateExecutive
rename emcond_1 ReasonStateEmergency_War
rename emcond_5 ReasonStateEmergency_Econ
rename hosdcond_1 ReasonHOSDismissal_Unrestricted
rename legdiss_1 HOSCanDismissLegislature
rename federal_3 FederalAutonomousIndigenous
rename federal_2 FederalState_Region
rename intorgs LegalProvisionsForIntOrgs
rename legsupr NewLawsRequireSuperMajority
rename intlaw LegalProvisionsForIntLaws
rename specleg_2 SpecialLegProcessForBudgetBills
rename amndapct_345 AdoptAmendmentRequires_60perc
rename specleg_5 SpecialLegProcessForSpendBills
rename standliv AdequateLivingStandardProvision
rename acfree AcademicFreedom
rename equal EqualRightsandNonDiscrimination
rename binding AllRightsBinding
rename seprel SeparationChurchandState
rename cc CounterCorruptionComission
rename healthr Healthcare
rename censor_12 CensorshipProhibited
rename debtors DebtorsCannotBeDetained
rename pubtri TrialsArePublic
rename falseimp FalseImprisonmentRedress
rename trilang TrialsInAccusedLanguage
rename rulelaw RuleOfLaw_GermanRechtsStaat
rename corppun CorporalPunishmentProhibited 
rename hosdcond_4 ReasonHOSDismissal_Violation
rename housenum	Housenum_1
rename hogsucc_12 HOGReplace_NoAutomaticSelection
rename votelim_1 VotingRestriction_Incapacitated
rename emcond_3 ReasonStateEmergency_Disaster
rename emcond_2 ReasonStateEmergency_Security
rename execindp IndependentExecutive
rename specleg_3 SpecialLegProcessForTaxBills
rename legappdf_4 ExecutiveSignsLegislation
rename emdecl_457 LegOrCabCanDeclareStateEmergency
rename unamend ConstPartsUnamendable
rename expcond_2456	ReasonExpropriation_Redist
rename selfdet RightToSelfDetermination
rename hoselsys_4567 HOSElection_Majority
rename uhage_under22 Chamber2MinAge_Below22
rename voteun UniversalSuffrage
rename federal_1 FederalLocal
rename war_47 LegDeclaresWar
rename bank CentralBank
rename judcrts_1 AdminCourts
rename fairtri FairTrial
rename taxes Taxes
rename habcorp NoUnjustifiedRestraint
rename illadmin ProtectionAgainstGovernment
rename achighed_1 HigherEducation
rename opgroup Opportunity
rename scifree ScientificProgress
rename structural SI_HJ
rename gadp SI_GADP

save UNBUNDLING_DATA, replace


*********************************************************************
* Writing datasets needed for the empirical analysis in Table 2:	*
*********************************************************************

*****************************************************
* SI-HJ - Unrestricted Dataset (Table 2, panel 1):	*
*****************************************************
order SI_HJ, alpha
drop country SI_GADP
outsheet using iBMA_Table2_panel1.csv, comma replace

*****************************************************
* SI-GADP - Unrestricted Dataset (Table 2, panel 3):*
*****************************************************
use UNBUNDLING_DATA, clear
order SI_GADP, alpha
drop country SI_HJ
outsheet using iBMA_Table2_panel3.csv, comma replace

*****************************************************
* SI-HJ - Restricted Dataset (Table 2, panel 2):	*
*****************************************************
use UNBUNDLING_DATA, clear

* Drop variables without clear theoretical linkages:
drop atgen CentralBank cappun comchief_1 couns cultrght depexec dueproc econplan ethincl ///
examwit_3 fedunit_3 hossucc_4 hr infoacc intprop_1234 jc AdminCourts legapp_1 libel ///
overpct_1_2 prerel presinoc reltax rghtapp ScientificProgress speedtri terr Chamber2MinAge_Below22 ///
war_13 LegDeclaresWar LegChamber1IsElected LegChamber2IsElected HOSElection_Majority ///
Opportunity hoselect_1 hoselect_3

* Merge some variables to more meaningful aggregates:
gen AdoptAmendmentRequires_50perc=0
replace AdoptAmendmentRequires_50perc=1 if AdoptAmendmentRequires_60perc==1|amndamaj==1
drop AdoptAmendmentRequires_60perc amndamaj 

gen Referenda=0
replace Referenda=1 if referen==1|initiat==1
drop referen initiat

replace ExecCanDeclareStateEmergency=1 if hogdec==1
drop hogdec

replace HOSReplace_NoAutomaticSelection=1 if HOSReplace_NoAutomaticSelection==1|hossucc_2==1
drop hossucc_2

gen Chamber2MembersAreNotElected=0
replace Chamber2MembersAreNotElected=1 if uhselect_1==1|uhselect_2==1
drop uhselect_1 uhselect_2

replace Healthcare=1 if healthf==1|provhlth==1
drop healthf provhlth

gen PublicMeetings=0
replace PublicMeetings=1 if pubmeet==1|pubmin==1
drop pubmeet pubmin

replace ReasonHOSDismissal_Violation=1 if hosdcond_2==1|hosdcond_3==1|hosdcond_5==1
drop hosdcond_2 hosdcond_3 hosdcond_5

* Deconstruct exprcomp variables:
gen exprcomp_2=0
local country="Denmark Finland Greece Hungary Iceland Netherlands Norway Peru Switzerland"
foreach c in `country' {
replace exprcomp_1234=0 if country=="`c'"
replace exprcomp_2=1 if country=="`c'"
}
rename exprcomp_1234 exprcomp_134

order SI_HJ, alpha
save panel4helper, replace
drop country SI_GADP
outsheet using iBMA_Table2_panel2.csv, comma replace

*****************************************************
* SI-GADP - Restricted Dataset (Table 2, panel 4):	*
*****************************************************
use panel4helper, clear
order SI_GADP, alpha
drop country SI_HJ
outsheet using iBMA_Table2_panel4.csv, comma replace
erase panel4helper.dta
erase UNBUNDLING_DATA.dta
